#include <FileWrapper.h>

namespace DataImporter_ns
{

//==============================================================================
//      FileWrapper::FileWrapper()
//==============================================================================
FileWrapper::FileWrapper(Tango::DeviceImpl* deviceImpl_p,
    boost::filesystem::path filePath, boost::uint64_t totalFileSize) :
    Tango::LogAdapter(deviceImpl_p), m_totalFileSize(totalFileSize)

{
    DEBUG_STREAM << "FileWrapper::FileWrapper()" << endl;

    m_outputFileStream.open(filePath.string(), std::ios::binary);
}

//==============================================================================
//      FileWrapper::~FileWrapper()
//==============================================================================
FileWrapper::~FileWrapper()
{
    DEBUG_STREAM << "FileWrapper::~FileWrapper()" << endl;

    m_outputFileStream.close();
}

//==============================================================================
//      FileWrapper::create()
//==============================================================================
FileWrapper::SP FileWrapper::create(Tango::DeviceImpl* deviceImpl_p,
    boost::filesystem::path filePath, boost::uint64_t totalFileSize)
{
    FileWrapper::SP d_sp(new FileWrapper(deviceImpl_p, filePath, totalFileSize),
        FileWrapper::Deleter());

    return d_sp;
}

//==============================================================================
//      FileWrapper::isOpen()
//==============================================================================
bool FileWrapper::isOpen()
{
    return m_outputFileStream.is_open();
}

//==============================================================================
//      FileWrapper::isBad()
//==============================================================================
bool FileWrapper::isBad()
{
    return m_outputFileStream.bad();
}

//==============================================================================
//      FileWrapper::isCompleted()
//==============================================================================
bool FileWrapper::isCompleted()
{
    return (boost::uint64_t)m_outputFileStream.tellp() >= m_totalFileSize;
}

//==============================================================================
//      FileWrapper::getLeftToWrite()
//==============================================================================
boost::uint64_t FileWrapper::getLeftToWrite()
{
    return m_totalFileSize - (boost::uint64_t)m_outputFileStream.tellp();
}

//==============================================================================
//      FileWrapper::read()
//==============================================================================
void FileWrapper::write(std::vector<char>& writeBuff, boost::uint64_t& recvBytes)
{
    m_outputFileStream.write(&writeBuff[0], (std::streamsize)recvBytes);
}

}
