#ifndef FILEWRAPPER_H
#define	FILEWRAPPER_H

#include <tango.h>

#include <boost/filesystem.hpp>

namespace DataImporter_ns
{

class FileWrapper : public Tango::LogAdapter
{
public:
//------------------------------------------------------------------------------
//  [Public] Shared pointer typedef
//------------------------------------------------------------------------------
    typedef boost::shared_ptr<FileWrapper> SP;

protected:
//------------------------------------------------------------------------------
//  [Protected] Constructor destructor deleter
//------------------------------------------------------------------------------
    FileWrapper(Tango::DeviceImpl*, boost::filesystem::path, boost::uint64_t);

    virtual ~FileWrapper();

    class Deleter;
    friend Deleter;
    class Deleter
    {
        public:
            void operator()(FileWrapper* d) { delete d; }
    };

public:
//------------------------------------------------------------------------------
//	[Public] Class creation method
//------------------------------------------------------------------------------
    static FileWrapper::SP create(Tango::DeviceImpl*,
        boost::filesystem::path, boost::uint64_t);

//------------------------------------------------------------------------------
//	[Public] Input stream methods
//------------------------------------------------------------------------------
    virtual bool isOpen();

    virtual bool isBad();

    virtual bool isCompleted();

    boost::uint64_t getLeftToWrite();

    virtual void write(std::vector<char>&, boost::uint64_t&);

protected:
//------------------------------------------------------------------------------
//  [Protected] Class variables
//------------------------------------------------------------------------------
    //Input file size
    boost::uint64_t m_totalFileSize;

    //Input file stream
    std::ofstream m_outputFileStream;
};

}   //End of namespace

#endif	/* FILEWRAPPER_H */
